@@ -29,6 +29,7 @@
 
 from supybot.test import *
 
+import time
 import copy
 import pickle
 
@@ -94,6 +95,11 @@ class IrcMsgTestCase(SupyTestCase):
                           ircmsgs.IrcMsg,
                           args=('foo', 'bar'),
                           prefix='foo!bar@baz')
+        m = ircmsgs.IrcMsg(prefix='foo!bar@baz', args=('foo', 'bar'),
+                            command='CMD')
+        self.assertIs(m.time, None)
+        m.time = 24
+        self.assertEqual(ircmsgs.IrcMsg(msg=m).time, 24)
 
     def testPickleCopy(self):
         for msg in msgs:
@@ -128,6 +134,29 @@ class IrcMsgTestCase(SupyTestCase):
         m.tag('repliedTo', 12)
         self.assertEqual(m.repliedTo, 12)
 
+    def testServerTags(self):
+        s = '@aaa=b\\:bb;ccc;example.com/ddd=ee\\\\se ' \
+            ':nick!ident@host.com PRIVMSG me :Hello'
+        m = ircmsgs.IrcMsg(s)
+        self.assertEqual(m.server_tags, {
+            'aaa': 'b;bb',
+            'ccc': None,
+            'example.com/ddd': 'ee\\se'})
+        self.assertEqual(m.prefix, 'nick!ident@host.com')
+        self.assertEqual(m.command, 'PRIVMSG')
+        self.assertEqual(m.args, ('me', 'Hello'))
+        self.assertEqual(str(m), s + '\n')
+
+    def testTime(self):
+        before = time.time()
+        msg = ircmsgs.IrcMsg('PRIVMSG #foo :foo')
+        after = time.time()
+        self.assertTrue(before <= msg.time <= after)
+
+        msg = ircmsgs.IrcMsg('@time=2011-10-19T16:40:51.620Z '
+                             ':Angel!angel@example.org PRIVMSG Wiz :Hello')
+        self.assertEqual(msg.time, 1319042451.62)
+
 class FunctionsTestCase(SupyTestCase):
     def testIsAction(self):
         L = [':jemfinch!~jfincher@ts26-2.homenet.ohio-state.edu PRIVMSG'
